Package: MortalityLaws
Type: Package
Title: Parametric Mortality Models, Life Tables and HMD
Version: 2.2.0
Authors@R: c(
  person("Marius D.", "Pascariu", role = c("aut", "cre", "cph"), email = "mpascariu@outlook.com", comment = c(ORCID = "0000-0002-2568-6489")),
  person("Vladimir", "Canudas-Romo", role = "ctb"))
Maintainer: Marius D. Pascariu <mpascariu@outlook.com>
Description: Fit the most popular human mortality 'laws', and construct 
  full and abridge life tables given various input indices. A mortality
  law is a parametric function that describes the dying-out process of 
  individuals in a population during a significant portion of their 
  life spans. For a comprehensive review of the most important mortality 
  laws see Tabeau (2001) <doi:10.1007/0-306-47562-6_1>. 
  Practical functions for downloading data from various human mortality 
  databases are provided as well.  
License: MIT + file LICENSE
LazyData: TRUE
Depends: R (>= 3.0.0)
Imports: RCurl (>= 1.95), pbapply (>= 1.3-4), tidyr (>= 0.8.1), rvest
        (>= 1.0.3), httr (>= 1.4.5), methods
Suggests: testthat, knitr, rmarkdown
URL: https://github.com/mpascariu/MortalityLaws
BugReports: https://github.com/mpascariu/MortalityLaws/issues
Encoding: UTF-8
RoxygenNote: 7.3.3
VignetteBuilder: knitr
NeedsCompilation: no
Packaged: 2026-05-05 06:43:17 UTC; masax
Author: Marius D. Pascariu [aut, cre, cph] (ORCID:
    <https://orcid.org/0000-0002-2568-6489>),
  Vladimir Canudas-Romo [ctb]
Repository: CRAN
Date/Publication: 2026-05-05 07:10:08 UTC
Built: R 4.6.0; ; 2026-05-05 08:34:49 UTC; unix
