# Generated by roxygen2: do not edit by hand

S3method(AIC,MortalityLaw)
S3method(deviance,MortalityLaw)
S3method(df.residual,MortalityLaw)
S3method(logLik,MortalityLaw)
S3method(plot,MortalityLaw)
S3method(predict,MortalityLaw)
S3method(print,LifeTable)
S3method(print,MortalityLaw)
S3method(print,ReadAHMD)
S3method(print,ReadCHMD)
S3method(print,ReadHMD)
S3method(print,ReadJMD)
S3method(print,availableLF)
S3method(print,availableLaws)
S3method(print,summary.MortalityLaw)
S3method(summary,MortalityLaw)
export(HP)
export(HP2)
export(HP3)
export(HP4)
export(LawTable)
export(LifeTable)
export(MortalityLaw)
export(ReadAHMD)
export(ReadCHMD)
export(ReadHMD)
export(ReadJMD)
export(availableHMD)
export(availableLF)
export(availableLaws)
export(beard)
export(beard_makeham)
export(carriere1)
export(carriere2)
export(convertFx)
export(ggompertz)
export(gompertz)
export(gompertz0)
export(invgompertz)
export(invweibull)
export(kannisto)
export(kannisto_makeham)
export(kostaki)
export(makeham)
export(makeham0)
export(martinelle)
export(opperman)
export(perks)
export(quadratic)
export(rogersplanck)
export(siler)
export(strehler_mildvan)
export(thiele)
export(vandermaen)
export(vandermaen2)
export(weibull)
export(wittstein)
import(httr)
import(rvest)
importFrom(RCurl,getURL)
importFrom(graphics,abline)
importFrom(graphics,axis)
importFrom(graphics,barplot)
importFrom(graphics,box)
importFrom(graphics,hist)
importFrom(graphics,layout)
importFrom(graphics,legend)
importFrom(graphics,lines)
importFrom(graphics,par)
importFrom(graphics,plot)
importFrom(graphics,rect)
importFrom(methods,is)
importFrom(pbapply,closepb)
importFrom(pbapply,setpb)
importFrom(pbapply,startpb)
importFrom(stats,coef)
importFrom(stats,df.residual)
importFrom(stats,fitted)
importFrom(stats,nlminb)
importFrom(stats,optim)
importFrom(stats,predict)
importFrom(stats,printCoefmat)
importFrom(stats,pt)
importFrom(stats,qt)
importFrom(stats,quantile)
importFrom(stats,vcov)
importFrom(tidyr,spread)
importFrom(utils,head)
importFrom(utils,read.csv)
importFrom(utils,read.table)
importFrom(utils,tail)
