# --------------------------------------------
# Author: Marius D PASCARIU
# Date: 2026-05-04 23:30:36
# --------------------------------------------

#' MortalityLaws Test Data
#'
#' Dataset containing altered death rates (mx), death counts (Dx)
#' and exposures (Ex) for the female population living in
#' England & Wales in four different years: 1850, 1900, 1950 and 2010.
#' This dataset is provided for testing purposes only.
#' Download the actual data free of charge from \url{https://www.mortality.org}.
#' Once a username and a password are created on the website, the function
#' \code{\link{ReadHMD}} can be used for downloading.
#'
#' @source \href{https://www.mortality.org}{Human Mortality Database}
#' @seealso \code{\link{ReadHMD}}
#' @examples head(ahmd$mx)
"ahmd"


#' HMD sample
#' Data object generated by the \code{ReadHMD()} function.
#' @return A sample of demographic data in a data.frame
#' @keywords internal
"HMD_sample"

#' AHMD sample
#' Data object generated by the \code{ReadAHMD()} function.
#' @return A sample of demographic data in a data.frame
#' @keywords internal
"AHMD_sample"

#' CHMD sample
#' Data object generated by the \code{ReadCHMD()} function.
#' @return A sample of demographic data in a data.frame
#' @keywords internal
"CHMD_sample"

#' JMD sample
#' Data object generated by the \code{ReadJMD()} function.
#' @return A sample of demographic data in a data.frame
#' @keywords internal
"JMD_sample"


