---
title: "`MortalityLaws` Installation"
author: "Marius D. Pascariu"
date: "January 10, 2018"
output: 
  pdf_document:
    highlight: tango
    number_sections: true
    toc: false
fontsize: 11pt
geometry: margin=1.1in
bibliography: Mlaw_Refrences.bib
biblio-style: "apalike"
link-citations: true
vignette: >
  %\VignetteEngine{knitr::rmarkdown}
  %\VignetteIndexEntry{Installation}
  %\VignetteEncoding{UTF-8}
---

```{r setup, include = FALSE}
knitr::opts_chunk$set(collapse = TRUE, comment = "#>")
```

The package can be installed from two different sources, `CRAN` or `GitHub`. Most people would choose the first option (see below).

# Install stable version from `CRAN`

The `MortalityLaws` package can be installed from [`CRAN`](https://cran.r-project.org/web/packages/MortalityLaws/index.html) as follows:

1. Make sure you have the most recent version of R
2. Run the following code in your R console 

```{r, eval=FALSE}
    install.packages("MortalityLaws")
```

# Updating to the latest version of the package
You can track and contribute to the development of `MortalityLaws` at https://github.com/mpascariu/MortalityLaws. To install it:

1. Install the release version of `devtools` from CRAN with
```{r, eval=FALSE}
    install.packages("devtools")
```

2. Make sure you have a working development environment.
    * **Windows**: Install [Rtools](https://cran.r-project.org/bin/windows/Rtools/).
    * **Mac**: Install `Xcode` from the Mac App Store.
    * **Linux**: Install a compiler and various development libraries (details vary across different flavors of Linux).

3. Install the development version of devtools.

```{r, eval=FALSE}
    devtools::install_github("mpascariu/MortalityLaws")
```


\vspace{2cm}

Now you are ready to go. Happy modelling!

Check the other vignettes and examples provided in the help pages.