% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/MortalityLaw_models.R
\name{perks}
\alias{perks}
\title{Perks Model - 1932}
\usage{
perks(x, par = NULL)
}
\arguments{
\item{x}{vector of age at the beginning of the age classes}

\item{par}{parameters of the selected model. If NULL the
default values will be assigned automatically.}
}
\value{
A list of rates and model parameters
}
\description{
Perks Model - 1932
}
\examples{
perks(x = 50:100)
}
\keyword{internal}
