% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/MortalityLaw_S3.R
\name{deviance.MortalityLaw}
\alias{deviance.MortalityLaw}
\title{deviance function for MortalityLaw}
\usage{
\method{deviance}{MortalityLaw}(object, ...)
}
\arguments{
\item{...}{further arguments passed to or from other methods.}
}
\value{
model deviance value
}
\description{
deviance function for MortalityLaw
}
\keyword{internal}
