% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/LifeTable.R
\name{dx_lx}
\alias{dx_lx}
\title{dx to lx}
\usage{
dx_lx(ux, out = c("dx", "lx"))
}
\arguments{
\item{ux}{A vector of dx or lx data.}

\item{out}{Type of the output: dx or lx.}
}
\value{
A vector containing dx or lx values
}
\description{
Function to convert dx into lx and back
}
\keyword{internal}
