% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/MortalityLaw_S3.R
\name{print.MortalityLaw}
\alias{print.MortalityLaw}
\title{Print MortalityLaw}
\usage{
\method{print}{MortalityLaw}(x, ...)
}
\arguments{
\item{x}{an object of class \code{"MortalityLaw"}}

\item{...}{further arguments passed to or from other methods.}
}
\value{
Print data on console
}
\description{
Print MortalityLaw
}
\keyword{internal}
