% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/readAHMD.R
\name{check_input_ReadAHMD}
\alias{check_input_ReadAHMD}
\title{Check input ReadAHMD}
\usage{
check_input_ReadAHMD(x)
}
\arguments{
\item{x}{a list containing the input arguments from ReadAHMD function}
}
\value{
No return value, called for checking stuff
}
\description{
Check input ReadAHMD
}
\keyword{internal}
