% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/readHMD.R
\name{data_format}
\alias{data_format}
\title{Data formats}
\usage{
data_format()
}
\value{
a vector
}
\description{
Data formats
}
\keyword{internal}
