% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/readAHMD.R
\name{AUSregions}
\alias{AUSregions}
\title{region codes}
\usage{
AUSregions()
}
\value{
a vector
}
\description{
region codes
}
\keyword{internal}
