% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/MortalityLaws-data.R
\docType{data}
\name{JMD_sample}
\alias{JMD_sample}
\title{JMD sample
Data object generated by the \code{ReadJMD()} function.}
\format{
An object of class \code{ReadJMD} of length 5.
}
\usage{
JMD_sample
}
\value{
A sample of demographic data in a data.frame
}
\description{
JMD sample
Data object generated by the \code{ReadJMD()} function.
}
\keyword{internal}
