% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/availableHMD.R
\name{availableHMD}
\alias{availableHMD}
\title{Check Data Availability in HMD}
\usage{
availableHMD(link = "https://www.mortality.org/Data/DataAvailability")
}
\arguments{
\item{link}{URL to the HMD available data.
Default: "https://www.mortality.org/Data/DataAvailability"}
}
\value{
A tibble.
}
\description{
Returns information about the data available in the Human Mortality 
Database (HMD), including the range of years covered by the life tables 
for each country or region.
}
\examples{
availableHMD()

}
\seealso{
\code{\link{ReadHMD}}
}
\author{
Marius D. Pascariu
}
