% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/MortalityLaws-data.R
\docType{data}
\name{CHMD_sample}
\alias{CHMD_sample}
\title{CHMD sample
Data object generated by the \code{ReadCHMD()} function.}
\format{
An object of class \code{ReadCHMD} of length 5.
}
\usage{
CHMD_sample
}
\value{
A sample of demographic data in a data.frame
}
\description{
CHMD sample
Data object generated by the \code{ReadCHMD()} function.
}
\keyword{internal}
