% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/MortalityLaw_models.R
\name{bring_parameters}
\alias{bring_parameters}
\title{Bring or Rename Starting Parameters in the Law Functions}
\usage{
bring_parameters(law, par = NULL)
}
\arguments{
\item{law}{The name of the mortality law to be used (e.g., \code{"gompertz"},
\code{"makeham"}). Run \code{\link{availableLaws}} to see all options.}

\item{par}{parameters of the selected model. If NULL the
default values will be assigned automatically.}
}
\value{
Vector or initial model parameters
}
\description{
Bring or Rename Starting Parameters in the Law Functions
}
\keyword{internal}
