% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/readCHMD.R
\name{CANregions}
\alias{CANregions}
\title{Country codes}
\usage{
CANregions()
}
\value{
a vector
}
\description{
Country codes
}
\keyword{internal}
