% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/readHMD.R
\name{HMDindices}
\alias{HMDindices}
\title{HMD Indices}
\usage{
HMDindices()
}
\value{
a vector
}
\description{
HMD Indices
}
\keyword{internal}
