% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/MortalityLaws-data.R
\docType{data}
\name{HMD_sample}
\alias{HMD_sample}
\title{HMD sample
Data object generated by the \code{ReadHMD()} function.}
\format{
An object of class \code{ReadHMD} of length 5.
}
\usage{
HMD_sample
}
\value{
A sample of demographic data in a data.frame
}
\description{
HMD sample
Data object generated by the \code{ReadHMD()} function.
}
\keyword{internal}
