% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/MortalityLaw_S3.R
\name{logLik.MortalityLaw}
\alias{logLik.MortalityLaw}
\title{logLik function for MortalityLaw}
\usage{
\method{logLik}{MortalityLaw}(object, ...)
}
\arguments{
\item{...}{further arguments passed to or from other methods.}
}
\value{
Model log-likelihood value
}
\description{
logLik function for MortalityLaw
}
\keyword{internal}
