% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/readHMD.R
\name{saveMsg}
\alias{saveMsg}
\title{Print message when saving an object}
\usage{
saveMsg()
}
\value{
No return value, called for side effects
}
\description{
Print message when saving an object
}
\keyword{internal}
