% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/utils.R
\name{substrRight}
\alias{substrRight}
\title{Extracting the last n characters from a string}
\usage{
substrRight(x, n)
}
\arguments{
\item{x}{a string}

\item{n}{number of characters}
}
\value{
A character vector of length n
}
\description{
Extracting the last n characters from a string
}
\keyword{internal}
