% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/availableLaws.R
\name{print.availableLaws}
\alias{print.availableLaws}
\title{Print availableLaws}
\usage{
\method{print}{availableLaws}(x, ...)
}
\arguments{
\item{x}{An object of class \code{"availableLaws"}}

\item{...}{Further arguments passed to or from other methods.}
}
\value{
print info on the console
}
\description{
Print availableLaws
}
\keyword{internal}
