% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/graphics.R
\name{plot.MortalityLaw}
\alias{plot.MortalityLaw}
\title{Plot Method for MortalityLaw}
\usage{
\method{plot}{MortalityLaw}(x, ...)
}
\arguments{
\item{x}{An object of class \code{"MortalityLaw"}.}

\item{...}{Further arguments passed to graphical methods, such as
parameters (see \code{\link{par}}).}
}
\value{
A plot is generated as a side effect.
}
\description{
Plot Method for MortalityLaw
}
\examples{
# See complete example in MortalityLaw help page
}
\seealso{
\code{\link{MortalityLaw}}
}
\author{
Marius D. Pascariu
}
