% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/readCHMD.R
\name{check_input_ReadCHMD}
\alias{check_input_ReadCHMD}
\title{Check input for ReadCHMD}
\usage{
check_input_ReadCHMD(x)
}
\arguments{
\item{x}{A list with the input values for ReadCHMD}
}
\value{
No return value, called for input validation
}
\description{
Check input for ReadCHMD
}
\keyword{internal}
