% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/MortalityLaws-data.R
\docType{data}
\name{ahmd}
\alias{ahmd}
\title{MortalityLaws Test Data}
\format{
An object of class \code{list} of length 3.
}
\source{
\href{https://www.mortality.org}{Human Mortality Database}
}
\usage{
ahmd
}
\description{
Dataset containing altered death rates (mx), death counts (Dx)
and exposures (Ex) for the female population living in
England & Wales in four different years: 1850, 1900, 1950 and 2010.
This dataset is provided for testing purposes only.
Download the actual data free of charge from \url{https://www.mortality.org}.
Once a username and a password are created on the website, the function
\code{\link{ReadHMD}} can be used for downloading.
}
\examples{
head(ahmd$mx)
}
\seealso{
\code{\link{ReadHMD}}
}
\keyword{datasets}
