% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/LifeTable.R
\name{LifeTable.check}
\alias{LifeTable.check}
\title{Check LifeTable input}
\usage{
LifeTable.check(input)
}
\arguments{
\item{input}{A list containing the input arguments of the LifeTable functions.}
}
\value{
A list of life table validated data
}
\description{
Check LifeTable input
}
\keyword{internal}
