% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/readHMD.R
\name{saveOutput}
\alias{saveOutput}
\title{Save Output in the working directory}
\usage{
saveOutput(out, show, prefix)
}
\arguments{
\item{out}{Output file}

\item{show}{Choose whether to display a progress bar. Logical.
Default: \code{TRUE}.}
}
\value{
No return value, called for side effects
}
\description{
Save Output in the working directory
}
\keyword{internal}
