% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/availableHMD.R
\name{make_http_request}
\alias{make_http_request}
\title{Make HTTP request}
\usage{
make_http_request(url)
}
\arguments{
\item{url}{URL}
}
\value{
url response
}
\description{
Make HTTP request
}
\keyword{internal}
