% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/MortalityLaw_S3.R
\name{df.residual.MortalityLaw}
\alias{df.residual.MortalityLaw}
\title{df.residual function for MortalityLaw}
\usage{
\method{df.residual}{MortalityLaw}(object, ...)
}
\arguments{
\item{...}{further arguments passed to or from other methods.}
}
\value{
model residual value
}
\description{
df.residual function for MortalityLaw
}
\keyword{internal}
