% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/MortalityLaw_S3.R
\name{summary.MortalityLaw}
\alias{summary.MortalityLaw}
\title{Summary MortalityLaw}
\usage{
\method{summary}{MortalityLaw}(object, ..., digits = max(3L, getOption("digits") - 3L))
}
\arguments{
\item{object}{an object of class \code{"MortalityLaw"}}

\item{...}{additional arguments affecting the summary produced.}

\item{digits}{number of digits to display.}
}
\value{
A list of model diagnosis
}
\description{
Summary MortalityLaw
}
\keyword{internal}
