% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/MortalityLaw_S3.R
\name{AIC.MortalityLaw}
\alias{AIC.MortalityLaw}
\title{AIC function for MortalityLaw}
\usage{
\method{AIC}{MortalityLaw}(object, ...)
}
\arguments{
\item{...}{further arguments passed to or from other methods.}
}
\value{
model AIC value
}
\description{
AIC function for MortalityLaw
}
\keyword{internal}
