% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/MortalityLaw_models.R
\name{invweibull}
\alias{invweibull}
\title{Inverse-Weibull Mortality Law}
\usage{
invweibull(x, par = NULL)
}
\arguments{
\item{x}{vector of age at the beginning of the age classes}

\item{par}{parameters of the selected model. If NULL the
default values will be assigned automatically.}
}
\value{
A list of rates and model parameters
}
\description{
The Inverse-Weibull proves useful for modelling the childhood and teenage years,
because the logarithm of h(x) is a concave function.
m > 0 is a measure of location
sigma > 0 is measure of dispersion
}
\examples{
invweibull(x = 1:20)
}
\keyword{internal}
