% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/MortalityLaw_models.R
\name{invgompertz}
\alias{invgompertz}
\title{Inverse-Gompertz Mortality Law - informative parameterization}
\usage{
invgompertz(x, par = NULL)
}
\arguments{
\item{x}{vector of age at the beginning of the age classes}

\item{par}{parameters of the selected model. If NULL the
default values will be assigned automatically.}
}
\value{
A list of rates and model parameters
}
\description{
m - is a measure of location because it is the mode of the density, m > 0
sigma - represents the dispersion of the density about the mode, sigma > 0
}
\examples{
invgompertz(x = 15:25)
}
\keyword{internal}
