% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/LifeTable.R
\name{mx_qx}
\alias{mx_qx}
\title{mx to qx}
\usage{
mx_qx(x, nx, ux, out = c("qx", "mx"))
}
\arguments{
\item{x}{Numeric vector of ages at the beginning of each age interval. 
For a full life table, use single-year ages (e.g., \code{0:110}). 
For an abridged life table, use the lower bound of each interval 
(e.g., \code{c(0, 1, 5, 10, ..., 110)}).}

\item{nx}{Length of the age-intervals.}

\item{ux}{A vector of mx or qx.}

\item{out}{Type of the output: mx or qx.}
}
\value{
A vector of rates
}
\description{
Function to convert mx into qx and back, using the constant force of
mortality assumption (CFM).
}
\keyword{internal}
