% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/readJMD.R
\name{print.ReadJMD}
\alias{print.ReadJMD}
\title{Print ReadJMD}
\usage{
\method{print}{ReadJMD}(x, ...)
}
\arguments{
\item{x}{An object of class \code{"ReadJMD"}}

\item{...}{Further arguments passed to or from other methods.}
}
\value{
Print info on the console
}
\description{
Print ReadJMD
}
\keyword{internal}
