% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/readCHMD.R
\name{print.ReadCHMD}
\alias{print.ReadCHMD}
\title{Print ReadCHMD}
\usage{
\method{print}{ReadCHMD}(x, ...)
}
\arguments{
\item{x}{An object of class \code{"ReadCHMD"}}

\item{...}{Further arguments passed to or from other methods.}
}
\value{
Print data on the console
}
\description{
Print ReadCHMD
}
\keyword{internal}
