% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/readHMD.R
\name{ageMsg}
\alias{ageMsg}
\title{What age(s) are we looking at?}
\usage{
ageMsg(what, x)
}
\arguments{
\item{x}{An object of class \code{"ReadHMD"}}
}
\value{
A scalar or character indicating age groups
}
\description{
What age(s) are we looking at?
}
\keyword{internal}
