% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/LifeTable.R
\name{compute.ax}
\alias{compute.ax}
\title{Find ax indicator}
\usage{
compute.ax(x, mx, qx)
}
\arguments{
\item{x}{Numeric vector of ages at the beginning of each age interval. 
For a full life table, use single-year ages (e.g., \code{0:110}). 
For an abridged life table, use the lower bound of each interval 
(e.g., \code{c(0, 1, 5, 10, ..., 110)}).}

\item{mx}{Age-specific death rate in the age interval \code{[x, x+n)}. 
Defined as \code{Dx / Ex}.}

\item{qx}{Probability of dying within the age interval \code{[x, x+n)}.}
}
\value{
\code{ax} - the point in the age interval where 50% of the deaths
have already occurred
}
\description{
Find ax indicator
}
\keyword{internal}
