% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/MortalityLaw_models.R
\name{ggompertz}
\alias{ggompertz}
\title{Gamma-Gompertz Model as in Vaupel et al. (1979)}
\usage{
ggompertz(x, par = NULL)
}
\arguments{
\item{x}{vector of age at the beginning of the age classes}

\item{par}{parameters of the selected model. If NULL the
default values will be assigned automatically.}
}
\value{
A list of rates and model parameters
}
\description{
Gamma-Gompertz Model as in Vaupel et al. (1979)
}
\examples{
ggompertz(x = 50:120)
}
\keyword{internal}
