% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/MortalityLaw_models.R
\name{weibull}
\alias{weibull}
\title{Weibull Mortality Law - 1939}
\usage{
weibull(x, par = NULL)
}
\arguments{
\item{x}{vector of age at the beginning of the age classes}

\item{par}{parameters of the selected model. If NULL the
default values will be assigned automatically.}
}
\value{
A list of rates and model parameters
}
\description{
Note that if sigma > m, then the mode of the density is 0 and hx is a
non-increasing function of x, while if sigma < m, then the mode is
greater than 0 and hx is an increasing function.
m > 0 is a measure of location
sigma > 0 is measure of dispersion
}
\examples{
weibull(x = 1:20)
}
\keyword{internal}
