% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/LifeTable.R
\name{find.my.case}
\alias{find.my.case}
\title{Function that identifies the case/problem we have to solve}
\usage{
find.my.case(Dx = NULL, Ex = NULL, mx = NULL, qx = NULL, lx = NULL, dx = NULL)
}
\arguments{
\item{Dx}{Death counts. Each element represents the total number of 
deaths during the calendar year to persons aged \code{x} to 
\code{x + n} (where \code{n} is the length of the age interval). 
Must be provided together with \code{Ex}.}

\item{Ex}{Exposure-to-risk in the period. This is usually approximated 
by the mid-year population aged \code{x} to \code{x + n}. Must be 
provided together with \code{Dx}.}

\item{mx}{Age-specific death rate in the age interval \code{[x, x+n)}. 
Defined as \code{Dx / Ex}.}

\item{qx}{Probability of dying within the age interval \code{[x, x+n)}.}

\item{lx}{Probability of surviving to exact age \code{x} (if \code{lx0 = 1}), 
or the number of survivors at exact age \code{x} (if \code{lx0 > 1}). 
When \code{lx} is the sole input, the values are re-scaled to the 
chosen radix \code{lx0}.}

\item{dx}{Number of deaths in the life-table population occurring in 
the age interval \code{[x, x+n)}. When \code{dx} is the sole input, 
the values are re-scaled to sum to \code{lx0}.}
}
\value{
A list containing problem solving details
}
\description{
Function that identifies the case/problem we have to solve
}
\keyword{internal}
