% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/readJMD.R
\name{JPNregions}
\alias{JPNregions}
\title{region codes}
\usage{
JPNregions()
}
\value{
the vector
}
\description{
region codes
}
\keyword{internal}
