% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/MortalityLaw_check.R
\name{check.MortalityLaw}
\alias{check.MortalityLaw}
\title{Function to check input data in MortalityLaw}
\usage{
check.MortalityLaw(input)
}
\arguments{
\item{input}{A list containing all input arguments to \code{\link{MortalityLaw}}.}
}
\value{
No return value, called for side effects
}
\description{
Function to check input data in MortalityLaw
}
\keyword{internal}
